﻿using GeoAPI.Geometries;
using NAisParser;
using NetTopologySuite.Geometries;
using System;
using System.Collections.Generic;
using System.Text;
using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.SignalR.Models;

namespace Madart.OperationalUI.Common.Extensions.DataAccess
{
	public static class VesselStateExtensions
	{
		/// <summary>
		/// Maps info from a MessageType123 message to a VesselState
		/// </summary>
		/// <param name="vesselState">VesselState to map data to</param>
		/// <param name="message">MessageType123 to map data from</param>
		/// <returns>vesselState with data from the MessageType123</returns>
		public static VesselState MapFrom(this VesselState vesselState, MessageType123 message)
		{
			var position = new Point(message.Longitude, message.Latitude);

			vesselState.VesselStateId = 0;
			vesselState.VesselId = null;
			vesselState.TypeByte = new byte[] { message.Type };
			vesselState.RepeatByte = new byte[] { message.Repeat };
			vesselState.PositionAccuracy = message.PositionAccuracy;
			vesselState.MmsiNo = message.Mmsi;
			vesselState.Status = message.Status.ToString();
			vesselState.SpeedOverGround = message.SpeedOverGround;
			vesselState.Position = position;
			vesselState.CourseOverGround = message.CourseOverGround;
			vesselState.TrueHeading = message.TrueHeading;
			vesselState.TimeStamp = message.TimeStamp;
			vesselState.ManueverIndicator = message.ManeuverIndicator.ToString();
			vesselState.RaimFlag = message.RaimFlag;
			vesselState.RadioStatus = message.RadioStatus;


			//new VesselState(0, null, new byte[] { message.Type }, new byte[] { message.Repeat }, message.PositionAccuracy,
			//	message.Mmsi, message.Status.ToString(), message.SpeedOverGround, position,
			//	message.CourseOverGround, message.TrueHeading, message.TimeStamp, message.ManeuverIndicator.ToString(), message.RaimFlag, message.RadioStatus));


			return vesselState;
		}

		/// <summary>
		/// Maps info from a VesselState message to a CurrentVesselState
		/// </summary>
		/// <param name="currentVesselState">CurrentVesselState to map data to</param>
		/// <param name="vesselState">VesselState to map data from</param>
		/// <returns>CurrentVesselState with data from the VesselState</returns>
		public static CurrentVesselState MapFrom(this CurrentVesselState currentVesselState, VesselState vesselState)
		{
			currentVesselState.VesselStateId = vesselState.VesselStateId;
			currentVesselState.VesselId = vesselState.VesselId;
			currentVesselState.MmsiNo = vesselState.MmsiNo;
			currentVesselState.Status = vesselState.Status;
			currentVesselState.SpeedOverGround = vesselState.SpeedOverGround;
			currentVesselState.Position = vesselState.Position;
			currentVesselState.CourseOverGround = vesselState.CourseOverGround;
			currentVesselState.RadioStatus = vesselState.RadioStatus;
			currentVesselState.RelDistStd = vesselState.RelDistStd;
			currentVesselState.RelDistMax = vesselState.RelDistMax;
			currentVesselState.DistToP = vesselState.DistToP;
			currentVesselState.TimeReceived = vesselState.TimeReceived;
			currentVesselState.NormalRouteId = vesselState.NormalRouteId;
			

			return currentVesselState;
		}
	}
}
