﻿using System;
using Madart.OperationalUI.DataAccess.Models;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata;

namespace Madart.OperationalUI.DataAccess
{
    public partial class MadartDbContext : DbContext
    {
        public MadartDbContext()
        {
        }

        public MadartDbContext(DbContextOptions<MadartDbContext> options)
            : base(options)
        {
        }

        public virtual DbSet<Country> Country { get; set; }
        public virtual DbSet<GravityVector> GravityVector { get; set; }
        public virtual DbSet<Location> Location { get; set; }
        public virtual DbSet<LocationType> LocationType { get; set; }
        public virtual DbSet<NormalRoute> NormalRoute { get; set; }
        public virtual DbSet<Vessel> Vessel { get; set; }
        public virtual DbSet<VesselFlagCode> VesselFlagCode { get; set; }
        public virtual DbSet<VesselState> VesselState { get; set; }
        public virtual DbSet<VesselType> VesselType { get; set; }
        public virtual DbSet<VesselTypeGroup> VesselTypeGroup { get; set; }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {


            optionsBuilder.UseNpgsql("Host=127.0.0.1;Port=5432;Database=MADART1;Username=gvtk;Password=gvtk",
                   o => o.UseNetTopologySuite());

        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
			modelBuilder.ForNpgsqlUseIdentityColumns();
			modelBuilder.ForNpgsqlHasEnum(null, "person_on_board_type_enum", new[] { "CREW", "PAX" })
                .HasPostgresExtension("postgis")
                .HasAnnotation("ProductVersion", "2.2.1-servicing-10028");

            modelBuilder.Entity<Country>(entity =>
            {
                entity.Property(e => e.CountryId)
                    .HasColumnName("CountryID")
                    .ValueGeneratedNever();

                entity.Property(e => e.CountryNameEng).HasColumnType("character varying");

                entity.Property(e => e.CountryNameNor).HasColumnType("character varying");

                entity.Property(e => e.IsWithinEu).HasColumnName("IsWithinEU");

                entity.Property(e => e.ThreeCharCode).HasColumnType("character varying");

                entity.Property(e => e.TwoCharCode).HasColumnType("character varying");
            });

            modelBuilder.Entity<GravityVector>(entity =>
            {
                entity.HasIndex(e => e.NormalRouteId)
                    .HasName("normalrouteid_idx");

                entity.HasIndex(e => e.PositionGeometry)
                    .HasName("gravityvector_positiongeometry_idx")
                    .ForNpgsqlHasMethod("gist");

                entity.HasIndex(e => new { e.Latitude, e.Longitude, e.SpeedOverGround, e.CourseOverGround, e.Eta, e.EtalowerStd, e.EtaupperStd, e.DataCount })
                    .HasName("filter_idx");

                entity.Property(e => e.GravityVectorId)
                    .HasColumnName("GravityVectorID")
                    .HasDefaultValueSql("nextval('\"GravityVector_gravityvectorid_seq\"'::regclass)");

                entity.Property(e => e.Eta).HasColumnName("ETA");

                entity.Property(e => e.EtalowerStd).HasColumnName("ETALowerStd");

                entity.Property(e => e.EtaupperStd).HasColumnName("ETAUpperStd");

                entity.Property(e => e.GridId).HasColumnName("GridID");

                entity.Property(e => e.NormalRouteId).HasColumnName("NormalRouteID");

                entity.Property(e => e.PositionGeometry).IsRequired();

                entity.Property(e => e.SerialId).HasColumnName("SerialID");

                entity.HasOne(d => d.NormalRoute)
                    .WithMany(p => p.GravityVector)
                    .HasForeignKey(d => d.NormalRouteId)
                    .HasConstraintName("fkb41719d77e69f317");
            });

            modelBuilder.Entity<Location>(entity =>
            {
                entity.Property(e => e.LocationId)
                    .HasColumnName("LocationID")
                    .ValueGeneratedNever();

                entity.Property(e => e.CountryId).HasColumnName("CountryID");

                entity.Property(e => e.Description).HasColumnType("character varying");

                entity.Property(e => e.LocatedInLocationId).HasColumnName("LocatedInLocationID");

                entity.Property(e => e.LocationCode).HasColumnType("character varying");

                entity.Property(e => e.LocationNameEng).HasColumnType("character varying");

                entity.Property(e => e.LocationNameNor).HasColumnType("character varying");

                entity.Property(e => e.LocationSourceId).HasColumnName("LocationSourceID");

                entity.Property(e => e.LocationTypeId).HasColumnName("LocationTypeID");

                entity.Property(e => e.PostCode).HasMaxLength(20);

                entity.HasOne(d => d.Country)
                    .WithMany(p => p.Location)
                    .HasForeignKey(d => d.CountryId)
                    .HasConstraintName("Location_CountryID_fkey");

                entity.HasOne(d => d.LocatedInLocation)
                    .WithMany(p => p.InverseLocatedInLocation)
                    .HasForeignKey(d => d.LocatedInLocationId)
                    .HasConstraintName("Location_LocatedInLocationID_fkey");

                entity.HasOne(d => d.LocationType)
                    .WithMany(p => p.Location)
                    .HasForeignKey(d => d.LocationTypeId)
                    .HasConstraintName("Location_LocationTypeID_fkey");
            });

            modelBuilder.Entity<LocationType>(entity =>
            {
                entity.Property(e => e.LocationTypeId)
                    .HasColumnName("LocationTypeID")
                    .ValueGeneratedNever();

                entity.Property(e => e.DescriptionEng).HasColumnType("character varying");

                entity.Property(e => e.DescriptionNor).HasColumnType("character varying");

                entity.Property(e => e.LocationTypeEng).HasColumnType("character varying");

                entity.Property(e => e.LocationTypeNor).HasColumnType("character varying");

                entity.Property(e => e.SystemName).HasColumnType("character varying");
            });

            modelBuilder.Entity<NormalRoute>(entity =>
            {
                entity.HasIndex(e => e.HighError)
                    .HasName("higherror_idx");

                entity.HasIndex(e => e.NormalRouteGeometry)
                    .HasName("normalroute_normalroutegeometry_idx")
                    .ForNpgsqlHasMethod("gist");

                entity.HasIndex(e => e.VoyageCount)
                    .HasName("voyagecount_idx");

                entity.HasIndex(e => new { e.FromLocationId, e.ToLocationId })
                    .HasName("fromlocationtolocation_idx");

                entity.Property(e => e.NormalRouteId)
                    .HasColumnName("NormalRouteID")
                    .ValueGeneratedNever();

                entity.Property(e => e.FromLocationId).HasColumnName("FromLocationID");

                entity.Property(e => e.ToLocationId).HasColumnName("ToLocationID");
            });

            modelBuilder.Entity<Vessel>(entity =>
            {
                entity.Property(e => e.VesselId)
                    .HasColumnName("VesselID")
					.HasDefaultValueSql("nextval('\"Vessel_vesselid_seq\"')" );

                entity.Property(e => e.CallSign).HasColumnType("character varying");

                entity.Property(e => e.Dwt).HasColumnName("DWT");

                entity.Property(e => e.VesselBreadthTypeId).HasColumnName("VesselBreadthTypeID");

                entity.Property(e => e.VesselFlagCodeId).HasColumnName("VesselFlagCodeID");

                entity.Property(e => e.VesselLengthTypeId).HasColumnName("VesselLengthTypeID");

                entity.Property(e => e.VesselName).HasColumnType("character varying");

                entity.Property(e => e.VesselPowerTypeId).HasColumnName("VesselPowerTypeID");

                entity.Property(e => e.VesselSourceId).HasColumnName("VesselSourceID");

                entity.Property(e => e.VesselSpeedTypeId).HasColumnName("VesselSpeedTypeID");

                entity.Property(e => e.VesselStatusId).HasColumnName("VesselStatusID");

                entity.Property(e => e.VesselTypeId).HasColumnName("VesselTypeID");

				entity.Property(e => e.Description).HasColumnName("Description");


				entity.HasOne(d => d.VesselFlagCode)
                    .WithMany(p => p.Vessel)
                    .HasForeignKey(d => d.VesselFlagCodeId)
                    .HasConstraintName("Vessel_VesselFlagCodeID_fkey");

                entity.HasOne(d => d.VesselType)
                    .WithMany(p => p.Vessel)
                    .HasForeignKey(d => d.VesselTypeId)
                    .HasConstraintName("Vessel_VesselTypeID_fkey");
            });

            modelBuilder.Entity<VesselFlagCode>(entity =>
            {
                entity.Property(e => e.VesselFlagCodeId)
                    .HasColumnName("VesselFlagCodeID")
                    .ValueGeneratedNever();

                entity.Property(e => e.CountryId).HasColumnName("CountryID");

                entity.Property(e => e.Description).HasColumnType("character varying");

                entity.Property(e => e.SystemName).HasColumnType("character varying");

                entity.Property(e => e.VesselFlagCode1)
                    .HasColumnName("VesselFlagCode")
                    .HasColumnType("character varying");

                entity.HasOne(d => d.Country)
                    .WithMany(p => p.VesselFlagCode)
                    .HasForeignKey(d => d.CountryId)
                    .HasConstraintName("VesselFlagCode_CountryID_fkey");
            });

            modelBuilder.Entity<VesselState>(entity =>
            {
                entity.Property(e => e.VesselStateId)
                    .HasColumnName("VesselStateID")
                    .HasDefaultValueSql("nextval('\"VesselState_vessel_state_id_seq\"'::regclass)");

                entity.Property(e => e.ManueverIndicator).HasColumnType("character varying");

                entity.Property(e => e.NormalRouteId).HasColumnName("NormalRouteID");

                entity.Property(e => e.Status).HasColumnType("character varying");

                entity.Property(e => e.TimeReceived).HasColumnType("timestamp with time zone");

                entity.Property(e => e.VesselId).HasColumnName("VesselID");

                entity.HasOne(d => d.NormalRoute)
                    .WithMany(p => p.VesselState)
                    .HasForeignKey(d => d.NormalRouteId)
                    .HasConstraintName("VesselState_NormalRouteID_fkey");

                entity.HasOne(d => d.Vessel)
                    .WithMany(p => p.VesselState)
                    .HasForeignKey(d => d.VesselId)
                    .HasConstraintName("VesselState_VesselID_fkey");
            });

            modelBuilder.Entity<VesselType>(entity =>
            {
                entity.Property(e => e.VesselTypeId)
                    .HasColumnName("VesselTypeID")
                    .ValueGeneratedNever();

                entity.Property(e => e.DescriptionEng).HasColumnType("character varying");

                entity.Property(e => e.DescriptionNor).HasColumnType("character varying");

                entity.Property(e => e.SystemName).HasColumnType("character varying");

                entity.Property(e => e.VesselTypeEng).HasColumnType("character varying");

                entity.Property(e => e.VesselTypeGroupId).HasColumnName("VesselTypeGroupID");

                entity.Property(e => e.VesselTypeNor).HasColumnType("character varying");

                entity.HasOne(d => d.VesselTypeGroup)
                    .WithMany(p => p.VesselType)
                    .HasForeignKey(d => d.VesselTypeGroupId)
                    .HasConstraintName("VesselType_VesselTypeGroupID_fkey");
            });

            modelBuilder.Entity<VesselTypeGroup>(entity =>
            {
                entity.Property(e => e.VesselTypeGroupId)
                    .HasColumnName("VesselTypeGroupID")
                    .ValueGeneratedNever();

                entity.Property(e => e.DescriptionEng).HasColumnType("character varying");

                entity.Property(e => e.DescriptionNor).HasColumnType("character varying");

                entity.Property(e => e.SystemName).HasColumnType("character varying");

                entity.Property(e => e.VesselTypeGroupCode).HasColumnType("character varying");

                entity.Property(e => e.VesselTypeGroupEng).HasColumnType("character varying");

                entity.Property(e => e.VesselTypeGroupNor).HasColumnType("character varying");
            });

            modelBuilder.HasSequence("claim_claim_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("fal_security_id_seq");

            modelBuilder.HasSequence("GravityVector_gravityvectorid_seq");

            modelBuilder.HasSequence("identity_document_id_seq");

            modelBuilder.HasSequence("identity_document_type_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("issc_id_seq");

            modelBuilder.HasSequence("password_password_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("person_on_board_id_seq");

            modelBuilder.HasSequence("person_person_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("role_role_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("ship_ship_id_seq")
                .StartsAt(359004)
                .HasMax(2147483647);

            modelBuilder.HasSequence("user_login_user_login_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("user_role_user_role_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("user_token_user_token_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("user_user_id_seq").HasMax(2147483647);

            modelBuilder.HasSequence("VesselState_vessel_state_id_seq");
        }
    }
}
