﻿using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.DataAccess.Repositories.Interface;
using NetTopologySuite.Geometries;
using System;
using System.Collections.Generic;
using System.Text;
using System.Linq;

namespace Madart.OperationalUI.DataAccess.Repositories
{
    public interface IGravityVectorRepository
    {
        Models.GravityVector GetGravityVector(Point position, int normalrouteId);
    }
    public class GravityVectorRepository : AbstractRepository<Models.GravityVector>, IGravityVectorRepository
    {
		/// <summary>
		/// Retrieves the GravityVector from a Normalroute closest to a position
		/// </summary>
		/// <param name="position">Point position the GravityVector is close to</param>
		/// <param name="normalrouteId">Id of the Normalroute the GravityVector is related to</param>
		/// <returns>GravityVector</returns>
        public Models.GravityVector GetGravityVector(Point position, int normalrouteId)
        {
            if(position == null)
            {
                return null;
            }
            var GravityVector = (from gv in Context.GravityVector
                                 where gv.NormalRouteId == normalrouteId
								 orderby gv.PositionGeometry.Distance(position)
                                 select gv).Take(1).ToList().FirstOrDefault();
            return GravityVector;
        }
    }
}
