﻿using GeoAPI.Geometries;
using NetTopologySuite.Geometries;

using System;
using System.Collections.Generic;
using System.Text;
using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.DataAccess.Repositories.Interface;
using System.Linq;

namespace Madart.OperationalUI.DataAccess.Repositories
{
    public interface ILocationRepository
    {
        Models.Location GetClosestLocation(Point warning);
        List<Models.Location> GetDeppAndArrLocations(int normalrouteId);
    }
    public class LocationRepository : AbstractRepository<Models.Location>, ILocationRepository
    {
		/// <summary>
		/// Gets the Location closest to a Point from the DB
		/// </summary>
		/// <param name="warning">The location Point af a warning</param>
		/// <returns>Closest Location in the DB</returns>
        public Models.Location GetClosestLocation(Point warning)
        {
            if (warning == null)
                return null;
            var LocationList = (from loc in Context.Location
                                where loc.LocationGeometry != null
                                orderby loc.LocationGeometry.Distance(warning)
                                select loc).Take(1).ToList();
            var closestLocation = LocationList.FirstOrDefault();
            return closestLocation;
        }

		/// <summary>
		/// Gets the Departure and Arrival Location to a normalroute given a normalrouteId
		/// </summary>
		/// <param name="normalrouteId">normalRouteId for a NormalRoute</param>
		/// <returns>List containing a Departure and Arrival Location</returns>
        public List<Models.Location> GetDeppAndArrLocations(int normalrouteId)
        {
            if (normalrouteId == null)
            {
                return null;
            }
            var deppLocation = (from normalRoute in Context.NormalRoute
                                join location in Context.Location on normalRoute.FromLocationId.ToString() equals location.LocationId.ToString()
                                where normalRoute.NormalRouteId == normalrouteId
                                select location).FirstOrDefault();

            var arrLocation = (from normalRoute in Context.NormalRoute
                               join location in Context.Location on normalRoute.ToLocationId.ToString() equals location.LocationId.ToString()
                               where normalRoute.NormalRouteId == normalrouteId
                               select location).FirstOrDefault();

            var list = new List<Models.Location>();
            list.Add(deppLocation);
            list.Add(arrLocation);
            return list;
        }
    }
}
