﻿using GeoAPI.Geometries;
using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.MadAPI.Models;
using NetTopologySuite.Geometries;
using System;
using System.Collections.Generic;
using System.Text;

namespace Madart.OperationalUI.SignalR.Models
{
    public class Warning
    {
        public int SkerrieCount, CoastPointCount, MmsiNo;
        public IPoint ClosestSkerry, ClosestCoastPoint;
		public List<IPoint>SectorPolygon;
        public double DistanceToClosestCoastPoint, DistanceToClosestSkerry, CoastPointTTI, SkerryPointTTI;
        public DateTime? TimeReceived;

        public Warning(DangerOfRunningAgroundOutput output, VesselState vesselState)
        {
            SkerrieCount = output.s_in_sector ?? 0;
            CoastPointCount = output.c_in_sector ?? 0;
            MmsiNo = vesselState.MmsiNo;
            TimeReceived = vesselState.TimeReceived;
            DistanceToClosestCoastPoint = output.coast_dist ?? 0;
            DistanceToClosestSkerry = output.skerry_dist ?? 0;
            CoastPointTTI = output.coast_tti ?? double.PositiveInfinity;
            SkerryPointTTI = output.skerry_tti ?? double.PositiveInfinity;
            ClosestSkerry = new Point(output.skerry_lon ?? 0, output.skerry_lat ?? 0);
            ClosestCoastPoint = new Point(output.coast_lon ?? 0, output.coast_lat ?? 0);
			SectorPolygon = new List<IPoint>();
			foreach(var e in output.sector_polygon)
			{
				SectorPolygon.Add(new Point(e[0]?? 0, e[1]??0));
			}
        }
    }
}
