﻿using GeoAPI.Geometries;
using Madart.OperationalUI.Common.Extensions.DataAccess;
using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.SignalR.Models;
using Madart.OperationalUI.WebApp.AIS;
using Madart.OperationalUI.WebApp.States;
using NAisParser;
using NetTopologySuite.Geometries;
using NUnit.Framework;
using System;
using System.Collections.Generic;
using System.Text;
using static Madart.OperationalUI.WebApp.AIS.AisMessageHandler;

namespace Madart.OperationalUI.Tests.ControllersAndHandlers
{
	class VesselStateValidatorTests
	{
		VesselState vesselstate;
		VesselStateCollection vesselStateManager;
		AisMessageHandler handler;
		CurrentVesselState currentVesselState;

		[SetUp]
		public void Setup()
		{
			handler = new AisMessageHandler();
			vesselStateManager = new VesselStateCollection();
			MessageType123 message = new MessageType123(new byte(), new byte(), 1234, 0, 0.0, 30, false, 90, 90, 100.0, 0, 0, 0, false, 0);
			vesselstate = new VesselState().MapFrom(message);
			currentVesselState = new CurrentVesselState().MapFrom(vesselstate);
		}

		[TearDown]
		public void Cleanup()
		{
			vesselStateManager.ClearState();
		}


		[Test]
		public void legalPosition_NorthPole()
		{
			VesselState vesselAtNorthPole = vesselstate;
			IPoint positionNorthPole = new Point(90, 90);
			vesselAtNorthPole.Position = positionNorthPole;
			bool legal = VesselStateValidator.IsPositionValid(vesselAtNorthPole);
			Assert.False(legal);
		}

		[Test]
		public void legalPosition_Ireland()
		{
			IPoint positionIreland = new Point(-9.33, 54.4);
			VesselState vesselAtIreland = vesselstate;
			vesselAtIreland.Position = positionIreland;
			bool legal = VesselStateValidator.IsPositionValid(vesselAtIreland);
			Assert.AreEqual(legal, false);
		}

		[Test]
		public void legalPosition_Trondheim()
		{
			IPoint positionTrondheim = new Point(10.3, 64.5);
			VesselState vesselAtTrondheim = vesselstate;
			vesselAtTrondheim.Position = positionTrondheim;
			bool legal = VesselStateValidator.IsPositionValid(vesselAtTrondheim);
			Assert.True(legal);
		}

		[Test]
		public void legalPosition_ZeroZero()
		{
			IPoint positionZeroZero = new Point(0, 0);
			VesselState vesselAtZeroZero = vesselstate;
			vesselAtZeroZero.Position = positionZeroZero;
			bool legal = VesselStateValidator.IsPositionValid(vesselAtZeroZero);
			Assert.False(legal);

		}
	}
}
