﻿using Madart.OperationalUI.DataAccess.Repositories;
using Madart.OperationalUI.SignalR.Models;
using NetTopologySuite.Geometries;
using System;
using System.Collections.Concurrent;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Threading.Tasks;

namespace Madart.OperationalUI.WebApp.States
{
	public interface IWarningCollection
	{
		void AddOrUpdate(Warning warning);
		bool CloseProximityToLocation(Warning warning);
	}
	public class WarningCollection :   IWarningCollection
	{
		private static ConcurrentDictionary<int, Warning> Warnings = new ConcurrentDictionary<int, Warning>();

		public void AddOrUpdate(Warning warning)
		{
			if (Warnings.ContainsKey(warning.MmsiNo))
			{
				Warnings[warning.MmsiNo] = warning;
			}
			else
			{
				Warnings.TryAdd(warning.MmsiNo, warning);
			}
		}
		/// <summary>
		/// Checks if a warning is close to a known location. Ignoring ones that return true allows us to filter a lot of non-interesting warnings
		/// </summary>
		/// <param name="warning">The warning we are checking for</param>
		/// <returns>True if the warning is within one kilometer from a location, false if not</returns>
		public bool CloseProximityToLocation(Warning warning)
		{
			var closestPoint = (Point) (warning.CoastPointTTI > warning.SkerryPointTTI ? warning.ClosestSkerry : warning.ClosestCoastPoint);
			LocationRepository locRepo = new LocationRepository();
			var closestLocation = locRepo.GetClosestLocation(closestPoint);
			if (closestLocation == null) return false;
			var distance = closestPoint.Distance(closestLocation.LocationGeometry);
			if (distance * 111.32 < 2) return true; // Closest coast/skerry is within one km from a Location, dismiss warning
			return false;
		}
		public static Warning ClearVesselWarning(int mmsiNo)
		{
			Warning temp = null;
			bool ok = Warnings.TryRemove(mmsiNo, out temp);

			return temp;
		}

		public List<Warning> GetAllCurrentWarnings()
		{
			return Warnings.Values.ToList<Warning>();
		}
	}
}
