﻿using Madart.OperationalUI.DataAccess.Repositories;
using Microsoft.Extensions.Hosting;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;

namespace Madart.OperationalUI.WebApp.Handlers
{ 
	public class VesselStateDatabaseCleaner : IHostedService
	{
		/// <summary>
		/// Timer object that makes our CleanOldVesselStates a timed service
		/// </summary>
		private Timer timer;
		IVesselStateRepository repository;
		public VesselStateDatabaseCleaner(IVesselStateRepository repo)
		{
			repository = repo;
		}

		public Task StartAsync(CancellationToken cancellationToken)
		{
			timer = new Timer(CleanOldVesselStates, null, TimeSpan.Zero, TimeSpan.FromHours(1));
			return Task.CompletedTask;
		}
		/// <summary>
		/// A method that cleans the database for vesselstates older than 24 hrs.
		/// </summary>
		/// <param name="state">nullobject- required to pass, but unused</param>
		private void CleanOldVesselStates(object state)
		{
			var now = DateTime.UtcNow;
			var TwentyFourHoursAgo = now.AddHours(-24);
			try
			{
				repository.CleanVesselStates(TwentyFourHoursAgo);
			}
			catch (Exception e)
			{
				Debug.WriteLine($"Error: {e.Message}");
				Debug.WriteLine(e.StackTrace);
			}
		}

		public Task StopAsync(CancellationToken cancellationToken)
		{
			timer.Dispose();
			return Task.CompletedTask;
		}
	}
}
