﻿
using Madart.OperationalUI.WebApp.AIS;
using Madart.OperationalUI.Hubs;
using Microsoft.AspNetCore.SignalR;
using Microsoft.Extensions.Hosting;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices;
using System.Threading;
using System.Threading.Tasks;
using Microsoft.Extensions.DependencyInjection;
using Madart.OperationalUI.WebApp.States;
using Madart.OperationalUI.DataAccess.Models;
using Madart.OperationalUI.AIS;
using Madart.OperationalUI.SignalR.Models;
using Madart.OperationalUI.DataAccess.Repositories;
using Madart.OperationalUI.Common.Extensions.DataAccess;

namespace Madart.OperationalUI.WebApp
{
	public interface IVesselUpdater
	{
		Task StartAsync(CancellationToken cancellationToken);
		Task StopAsync(CancellationToken cancellationToken);

	}

	public class VesselUpdater : IHostedService, IVesselUpdater
	{
		readonly string server = "153.44.253.15"; //HØYOPPLØST: 153.44.253.15, LAVOPPLØST 153.44.253.27
		readonly int port = 5631;

		protected readonly IVesselStateCollection VesselStateCollection;
		protected readonly IHubContext<VesselHub> HubContext;
		protected readonly AISListener AisListener;
		protected readonly AisMessageHandler AisMessageHandler;
		protected readonly IServiceProvider ServiceProvider;
		protected readonly AisUpdateHandler AisUpdateHandler;
		
		public VesselUpdater(IHubContext<VesselHub> hubContext, IServiceProvider serviceProvider)
		{
			AisListener = new AISListener();
			VesselStateCollection = serviceProvider.GetService<IVesselStateCollection>();
			AisUpdateHandler = new AisUpdateHandler(serviceProvider.GetService<IVesselRepository>());
			AisMessageHandler = new AisMessageHandler();
			HubContext = hubContext;
			ServiceProvider = serviceProvider;
		}
		/// <summary>
		/// This is the method that starts when the server starts up. It calls on the AisListener to start listening, and will create a HandleMessage thread when a new event is observed.
		/// </summary>
		/// <param name="cancellationToken">Unused</param>
		/// <returns></returns>
		public Task StartAsync(CancellationToken cancellationToken)
		{

			AisListener.OnMessage += async (s, args) =>
			{
				await AisMessageHandler.HandleMessageAsync(args, VesselStateCollection, HubContext, ServiceProvider);
			};
			AisListener.OnUpdate += async (s, args) =>
			{
				await AisUpdateHandler.HandleUpdateAsync(args, VesselStateCollection);
			};
			AisListener.StartStreamListener(server, port);
			return Task.CompletedTask;
		}

		public Task StopAsync(CancellationToken cancellationToken)
		{

			throw new NotImplementedException();
		}
	}
}
